package eu.eudat.depositinterface.dspacerepository.config;

import com.fasterxml.jackson.databind.ObjectMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.env.Environment;
import org.springframework.stereotype.Service;

import java.io.*;

@Service("dspaceConfigLoader")
public class ConfigLoaderImpl implements ConfigLoader{
    private static final Logger logger = LoggerFactory.getLogger(ConfigLoaderImpl.class);
    private static final ObjectMapper mapper = new ObjectMapper();

    private DSpaceConfig dspaceConfig;

    @Autowired
    private Environment environment;

    @Override
    public DSpaceConfig getDSpaceConfig() {
        if(dspaceConfig == null){
            try{
                dspaceConfig = mapper.readValue(getStreamFromPath(environment.getProperty("configuration.dspace")), DSpaceConfig.class);
            } catch (IOException e) {
                logger.error(e.getLocalizedMessage(), e);
            }
        }
        return dspaceConfig;
    }

    @Override
    public byte[] getLogo() {
        String logo = environment.getProperty("configuration.logo");
        InputStream logoStream;
        if(logo != null && !logo.isEmpty()) {
            logoStream = getStreamFromPath(logo);
        }
        else{
            logoStream = getClass().getClassLoader().getResourceAsStream("dspace.svg");
        }
        try {
            return (logoStream != null) ? logoStream.readAllBytes() : null;
        }
        catch (IOException e){
            logger.error(e.getMessage(), e);
            return null;
        }
    }

    private InputStream getStreamFromPath(String filePath) {
        try {
            return new FileInputStream(filePath);
        } catch (FileNotFoundException e) {
            logger.info("loading from classpath");
            return getClass().getClassLoader().getResourceAsStream(filePath);
        }
    }
}
